# ifndef yyTempFunctions
# define yyTempFunctions

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 26 "TempFunctions.puma" */



extern void (* TempFunctions_Exit) ARGS ((void));

extern void MakeTempFunctions ARGS ((tTree t));

extern void BeginTempFunctions ARGS ((void));
extern void CloseTempFunctions ARGS ((void));

# endif
